int PeakSegPDPALog
(int *data_vec, double *weight_vec, int data_count,
 int maxSegments,
 // the following matrices are for output, data_count x maxSegments.
 double *cost_mat,
 int *end_mat,
 double *mean_mat,
 int *intervals_mat);
void PeakSegPDPAInf
(int *data_vec, double *weight_vec, int data_count,
 int maxSegments,
 // the following matrices are for output, data_count x maxSegments.
 double *cost_mat,
 int *end_mat,
 double *mean_mat,
 int *intervals_mat);
